@@ -1,14 +1,14 @@
 def url_for(directory, public=False, **kwargs):
   from appyter.context import get_env
-  from appyter.util import safe_join, join_routes
+  from appyter.ext.urllib import join_url
   config = get_env()
   url = None
   if config['DEBUG']:
     # appyter debugging static serve mode in flask
     try:
-      from flask import url_for
+      from flask import url_for as _url_for
       modified_directory = '.'.join(('__main__', directory)) if directory == 'static' else directory
-      url = url_for(modified_directory, **kwargs)
+      url = _url_for(modified_directory, **kwargs)
     except:
       pass
   #
@@ -16,13 +16,13 @@ def url_for(directory, public=False, **kwargs):
     # url_for outside of flask
     filename = kwargs.get('filename', kwargs.get('path'))
     assert filename is not None
-    url = safe_join(config['PREFIX'], directory, filename)
+    url = join_url(config['PREFIX'], directory, filename)
   #
   if public:
     # url_for public modifier -- return the public facing url
     try:
       from flask import request
-      url = join_routes(request.url_root, url)[1:]
+      url = join_url(request.url_root, url)
     except:
       pass
   #
